"""
Massad bank

https://www.bankmassad.co.il/wps/portal/FibiMenu/Marketing/Private/ForeignCurrency/ForexOnline/Rates
Choose "Against Shekel" (״מול השקל״) tab

The data is directly taken from FIBI bank:
https://apps.fibi.co.il/Matach/matach.aspx

Use the `fibi` module instead.
"""
